@@ -11,6 +11,10 @@ if [ "$EUID" -ne 0 ]
   exit
 fi
 
+#if lsblk -lf | grep -iq lvm; then
+#    vgchange -a n $(vgs --noheadings -o vg_name | xargs)
+#fi
+
 crypt=""
 efi=""
 space=""
@@ -30,17 +34,16 @@ rm -f /root/boot
 rm -f /root/efi
 rm -f /root/disk
 
-
+set +e
 systemctl stop tuxedo-tomte.timer
-killall -9 tuxedo-tomte || true
+killall -9 tuxedo-tomte
+set -e
 
 logfile=/var/log/tux-install-log
 rm -f "$logfile"
 
 # prüfe ob Windows mit fastboot beendet wurde
 
-udevadm trigger || true
-udevadm settle || true
 if lsblk -lf -o NAME,FSTYPE | grep -q ntfs; then
     for i in $(lsblk -lf -o NAME,FSTYPE | awk '/ntfs/{print $1}'); do ntfs-3g.probe --readwrite /dev/"$i" || true; done &> /tmp/fastboot
 
@@ -77,6 +80,23 @@ case "$llang" in
         ;;
 esac
 
+if lsblk -lf | grep -iq lvm; then
+    if [ "$llang" = "de" ]; then
+	text_lvm="<font color='red'><br>Achtung!<br>
+Auf Ihrem System befindet sich ein Linux-System, installiert auf LVM-Datenträger(n). Ein solcher Datenträger kann nicht einfach verkleinert werden. 
+Somit ist eine parallele Installation von TUXEDO OS hier leider nicht möglich. Sollten Sie diesen Datenträger trotzdem auswählen, wird das derzeit installierte System überschrieben!
+</font><br><br>"
+    else
+	text_lvm="<font color='red'><br>Achtung!<br>
+Your system has a Linux system installed on LVM data storage. Such data storage cannot simply be reduced in size. This means that a parallel installation 
+of TUXEDO OS is unfortunately not possible here. If you select this data storage device anyway, the currently installed system will be overwritten!
+</font><br><br>"
+    fi
+    vgchange -a n $(vgs --noheadings -o vg_name | xargs)
+else
+    text_lvm=""
+fi
+
 
 check_memory() {
     # Prüfe, wieviel Ram im System steckt und schreibe das Ergebnis in 
@@ -114,7 +134,7 @@ check_bitlock() {
 check_crypt() {
     # Dialog, ob geführte verschlüsselte Installation erfolgen soll
     set +e
-    kdialog --title "$title2" --yesnocancel "<p>$text_cr1</p>" "<p>$text_crd1${mem_d}$text_crd2</p>" --yes-label "$cr_ja" --no-label "$cr_nein"
+    kdialog --title "$title2" --yesnocancel "<p>$text_cr1$text_lvm</p>" "<p>$text_crd1${mem_d}$text_crd2</p>" --yes-label "$cr_ja" --no-label "$cr_nein"
     dialog_exit=$?
     set -e
     case $dialog_exit in
@@ -122,11 +142,14 @@ check_crypt() {
 	    echo "crypt"
 	    ;;
 	1)
-	    set +e
+	    if [ "$text_lvm" ]; then
+		apt-get -y remove lvm2
+	    fi
 	    calamares
 	    exit 0
 	    ;;
 	*)
+	    pvscan --cache -aay
 	    exit 0
 	    ;;
     esac
@@ -137,15 +160,15 @@ check_efi() {
     if [[ -e /sys/firmware/efi ]]; then
 	efi="efi"
     else
-	set +e
+	if [ "$text_lvm" ]; then
+	    apt-get -y remove lvm2
+	fi
 	calamares
         exit 0
     fi
 }
 
 find_device() {
-    udevadm trigger || true
-    udevadm settle || true
     mount | grep '^/dev/' | awk '{print $1}' | sed 's/^\/dev\///; s/\([0-9]*\|p[0-9]*\)$//' | sort -u > /tmp/mounts
     # erzeuge eine Liste von devices die kleiner als 16 GB sind
     if lsblk -ldb -o NAME,SIZE | awk '$2 <= 16000000000 {print $1}'; then
@@ -173,6 +196,7 @@ find_device() {
     fi
     if [[ -z "$device" ]]; then
         kdialog --sorry "$text1"
+	pvscan --cache -aay
         exit 0
     fi
     echo "$device" > /root/disk
@@ -204,8 +228,6 @@ find_device() {
 
 # Finde heraus, ob es einen unpartitionieren Bereich von mind. 16000 MiB gibt.
 check_free() {
-    udevadm trigger || true
-    udevadm settle || true
     if ! parted -s /dev/"$device" print >/dev/null 2>&1; then
 	no_table="1"
         # Keine Partitionstabelle vorhanden → gesamte Platte frei
@@ -240,8 +262,6 @@ check_free() {
 
 # Generiere nutzbare Partitionsnummern für parted, auch bei lükenhafter Partitionstabelle
 count_part() {
-    udevadm trigger || true
-    udevadm settle || true
     parts=$(LANG=C blkid -c /dev/null | grep "$device" | awk -F\: '{print $1}' | sort | wc -l 2>/dev/null)
     # 1. Alle Partitionsnummern extrahieren und in ein Array speichern (statt einer Datei)
     mapfile -t existing_parts < <(parted /dev/"$device" print | awk '/^ [0-9]+/ {print $1}')
@@ -414,8 +434,6 @@ EOF
 use_full() {
     # Hinweis für den User, dass alle Daten gelöscht werden
     # in den Details wird die aktuelle Partitionierung der gewählten Platte angezeigt
-    udevadm trigger || true
-    udevadm settle || true
     disk=$(lsblk -d -o NAME,MODEL,ID-LINK | grep "$device" | sed 's/^\([^ ]*\) \(.*\)$/\2/' | sed 's/^[[:space:]]*//')
     lsblk -ln -o NAME,SIZE,FSTYPE | grep "$device" | awk 'BEGIN { printf "%-18s %-18s %-18s\n", "NAME", "SIZE", "Filesystem" }{ printf "%-18s %-18s %-18s\n", $1, $2, ($3 ? $3 : "-") }' > /tmp/detail.txt
     set +e
